@@ -10,7 +10,7 @@
  * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * NOTE: Do not use kdDebug() in this implementation because 
- *       it will be multithreaded. Use qDebug() instead. 
+ *       it will be multithreaded. Use tqDebug() instead. 
  *       See B.K.O #133026 for details.
  *
  * This program is free software; you can redistribute it
@@ -86,32 +86,32 @@ RawDecodingIface::~RawDecodingIface()
 TQByteArray RawDecodingIface::getICCProfilFromFile(KDcrawIface::RawDecodingSettings::OutputColorSpace colorSpace)
 {
     TQString filePath;
-    KGlobal::dirs()->addResourceType("profiles", KGlobal::dirs()->kde_default("data") + 
+    TDEGlobal::dirs()->addResourceType("profiles", TDEGlobal::dirs()->kde_default("data") + 
                                      "kipiplugin_rawconverter/profiles");
 
     switch(colorSpace)
     {
         case KDcrawIface::RawDecodingSettings::SRGB:
         {
-            filePath = KGlobal::dirs()->findResourceDir("profiles", "srgb.icm");
+            filePath = TDEGlobal::dirs()->findResourceDir("profiles", "srgb.icm");
             filePath.append("srgb.icm");
             break;
         }
         case KDcrawIface::RawDecodingSettings::ADOBERGB:
         {
-            filePath = KGlobal::dirs()->findResourceDir("profiles", "adobergb.icm");
+            filePath = TDEGlobal::dirs()->findResourceDir("profiles", "adobergb.icm");
             filePath.append("adobergb.icm");
             break;
         }
         case KDcrawIface::RawDecodingSettings::WIDEGAMMUT:
         {
-            filePath = KGlobal::dirs()->findResourceDir("profiles", "widegamut.icm");
+            filePath = TDEGlobal::dirs()->findResourceDir("profiles", "widegamut.icm");
             filePath.append("widegamut.icm");
             break;
         }
         case KDcrawIface::RawDecodingSettings::PROPHOTO:
         {
-            filePath = KGlobal::dirs()->findResourceDir("profiles", "prophoto.icm");
+            filePath = TDEGlobal::dirs()->findResourceDir("profiles", "prophoto.icm");
             filePath.append("prophoto.icm");
             break;
         }
@@ -221,7 +221,7 @@ bool RawDecodingIface::loadedFromDcraw(const TQString& filePath,
 
             if (!f) 
             {
-                qDebug("Failed to open JPEG file for writing");
+                tqDebug("Failed to open JPEG file for writing");
                 return false;
             }
 
@@ -282,7 +282,7 @@ bool RawDecodingIface::loadedFromDcraw(const TQString& filePath,
 
             if (!f) 
             {
-                qDebug("Failed to open PNG file for writing");
+                tqDebug("Failed to open PNG file for writing");
                 return false;
             }
 
@@ -364,7 +364,7 @@ bool RawDecodingIface::loadedFromDcraw(const TQString& filePath,
 
             if (!tif) 
             {
-                qDebug("Failed to open TIFF file for writing");
+                tqDebug("Failed to open TIFF file for writing");
                 return false;
             }
 
@@ -441,7 +441,7 @@ bool RawDecodingIface::loadedFromDcraw(const TQString& filePath,
 
                 if (!bufThumb)
                 {
-                    qDebug("Cannot allocate memory buffer for TIFF thumbnail.");
+                    tqDebug("Cannot allocate memory buffer for TIFF thumbnail.");
                     TIFFClose(tif);
                     return false;
                 }
@@ -462,7 +462,7 @@ bool RawDecodingIface::loadedFromDcraw(const TQString& filePath,
 
                     if (!TIFFWriteScanline(tif, bufThumb, y, 0))
                     {
-                        qDebug("Cannot write TIFF thumbnail to target file.");
+                        tqDebug("Cannot write TIFF thumbnail to target file.");
                         _TIFFfree(bufThumb);
                         TIFFClose(tif);
                         return false;
@@ -484,7 +484,7 @@ bool RawDecodingIface::loadedFromDcraw(const TQString& filePath,
             FILE* f = fopen(TQFile::encodeName(destPath), "wb");
             if (!f) 
             {
-                qDebug("Failed to open ppm file for writing");
+                tqDebug("Failed to open ppm file for writing");
                 return false;
             }
 
@@ -495,7 +495,7 @@ bool RawDecodingIface::loadedFromDcraw(const TQString& filePath,
         }
         default:
         {
-            qDebug("Invalid output file format");
+            tqDebug("Invalid output file format");
             return false;
         }
     }
@@ -526,7 +526,7 @@ void RawDecodingIface::writeRawProfile(png_struct *ping, png_info *ping_info, ch
 
     const uchar hex[16] = {'0','1','2','3','4','5','6','7','8','9','a','b','c','d','e','f'};
 
-    qDebug("Writing Raw profile: type=%s, length=%i", profile_type, (int)length);
+    tqDebug("Writing Raw profile: type=%s, length=%i", profile_type, (int)length);
 
     text               = (png_textp) png_malloc(ping, (png_uint_32) sizeof(png_text));
     description_length = strlen((const char *) profile_type);
